@@ -330,7 +330,7 @@ KviRegisteredUserDataBase::~KviRegisteredUserDataBase()
 
 KviRegisteredUser * KviRegisteredUserDataBase::addUser(const TQString & name)
 {
-	if(name.isEmpty()) return false;
+	if(name.isEmpty()) return 0;
 	if(m_pUserDict->find(name))return 0;
 	KviRegisteredUser * u = new KviRegisteredUser(name);
 	m_pUserDict->replace(u->name(),u); //u->name() because we're NOT copying keys!
@@ -340,7 +340,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addUser(const TQString & name)
 
 KviRegisteredUserGroup * KviRegisteredUserDataBase::addGroup(const TQString & name)
 {
-	if(name.isEmpty()) return false;
+	if(name.isEmpty()) return 0;
 	if(m_pGroupDict->find(name))return 0;
 	KviRegisteredUserGroup * pGroup = new KviRegisteredUserGroup(name);
 	m_pGroupDict->replace(pGroup->name(),pGroup); //u->name() because we're NOT copying keys!
@@ -592,7 +592,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::findMatchingUser(const TQString &
 KviRegisteredMask * KviRegisteredUserDataBase::findMatchingMask(const TQString & nick,const TQString &user,const TQString & host)
 {
 	// first lookup the nickname in the maskDict
-	if(nick.isEmpty()) return false;
+	if(nick.isEmpty()) return 0;
 	KviRegisteredMaskList * l = m_pMaskDict->find(nick);
 	if(l)
 	{
