@@ -291,7 +291,7 @@ void KviCustomToolBar::dragEnterEvent(TQDragEnterEvent *e)
 #else
 				boxLayout()->remove(m_pDraggedChild); // in case it was already added
 				boxLayout()->insertWidget(idx,m_pDraggedChild);
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 				// bleah ://///
 				insertWidget(-1,m_pDraggedChild->sizeHint().width(),m_pDraggedChild,idx);
 #endif
@@ -506,7 +506,7 @@ void KviCustomToolBar::drag(TQWidget * child,const TQPoint &pnt)
 #else
 	boxLayout()->remove(child);
 	boxLayout()->insertWidget(idx,child);
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	// bleah ://///
 	insertWidget(-1,child->width(),child,idx);
 #endif
@@ -645,7 +645,7 @@ bool KviCustomToolBar::eventFilter(TQObject *o,TQEvent *e)
 #else
 					boxLayout()->insertWidget(0,m_pMovedChild);
 					m_pMovedChild->show();
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 					// bleah ://///
 					insertWidget(-1,m_pMovedChild->width(),m_pMovedChild,0);
 #endif
