@@ -500,7 +500,7 @@ static KviDockWidget * dockwidget_find(KviFrame *f)
 		dockwidget.show
 	@description:
 		Shows the dock widget for the current frame window.[br]
-		The dock widget is a small widget that docks in the KDE panel.[br]
+		The dock widget is a small widget that docks in the TDE panel.[br]
 		It shows a small icon of the earth and eventually displays four squares
 		that cover this icon: the bottom left square appears when there is some new
 		text in any console window, the square becomes red if the text is highlighted.[br]
