@@ -831,9 +831,9 @@ static bool torrent_module_init(KviModule *m)
 	g_pDescriptorList = new KviPointerList<KviTorrentInterfaceDescriptor>;
 	g_pDescriptorList->setAutoDelete(true);
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	g_pDescriptorList->append(new KviKTorrentDCOPInterfaceDescriptor);
-#endif // COMPILE_KDE_SUPPORT
+#endif // COMPILE_TDE_SUPPORT
 
 	KviTorrentInterface::select(0);
 
